@@ -31,10 +31,12 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+ximport('Hubzero_Controller');
+
 /**
  * Primary controller for the Billboards component
  */
-class BillboardsController extends \Hubzero\Component\AdminController
+class BillboardsController extends Hubzero_Controller
 {
 	/**
 	 * Controller execute method, used for selecting the correct function based on task.  
@@ -88,7 +90,7 @@ class BillboardsController extends \Hubzero\Component\AdminController
 		$view->task = $this->_task;
 
 		// Get configuration
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 		$config = JFactory::getConfig();
 
 		// Incoming
@@ -175,18 +177,12 @@ class BillboardsController extends \Hubzero\Component\AdminController
 		}
 
 		// Grab the file location for the background images
-		$params = JComponentHelper::getParams('com_billboards');
+		$params =& JComponentHelper::getParams('com_billboards');
 		$view->image_location = $params->get('image_location', '/site/media/images/billboards/');
 
-		if (!is_dir(JPATH_ROOT . DS . ltrim($view->image_location, DS)))
-		{
-			jimport('joomla.file.folder');
-			JFolder::create(JPATH_ROOT . DS . ltrim($view->image_location, DS));
-		}
-
 		// Get the relative image location for building the links to the media manager
-		$mparams = JComponentHelper::getParams('com_media');
-		$view->media_path = $mparams->get('image_path', 'site/media/images');
+		$mparams =& JComponentHelper::getParams('com_media');
+		$view->media_path = $mparams->get('file_path', 'site/media');
 
 		// Make sure the image path is in the format that we need (i.e. remove any leading or trailing "/")
 		if (substr($view->media_path, 0, 1) != DS)
@@ -301,7 +297,7 @@ class BillboardsController extends \Hubzero\Component\AdminController
 		}
 
 		// Clear the component's cache
-		$cache = JFactory::getCache('com_billboards');
+		$cache =& JFactory::getCache('com_billboards');
 		$cache->clean();
 
 		// Redirect
@@ -433,7 +429,7 @@ class BillboardsController extends \Hubzero\Component\AdminController
 		$view->task = $this->_task;
 
 		// Get configuration
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 		$config = JFactory::getConfig();
 
 		// Get paging variables
@@ -591,7 +587,7 @@ class BillboardsController extends \Hubzero\Component\AdminController
 	 */
 	protected function ordering(&$row, $id, $query, $neworder = 0)
 	{
-		$db = JFactory::getDBO();
+		$db =& JFactory::getDBO();
 
 		if ($id) 
 		{
