@@ -30,17 +30,17 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-JToolBarHelper::title(JText::_('Members') . ': ' . JText::_('Plugins'), 'addedit.png');
+JToolBarHelper::title('<a href="index.php?option=' . $this->option . '">' . JText::_('Resources') . '</a>: <small><small>[' . JText::_('Plugins') . ']</small></small>', 'addedit.png');
 
 if ($this->html)
 {
 	echo $this->html;
-} else {
+} else { 
 	JToolBarHelper::cancel();
 ?>
 	<form action="index.php?option=<?php echo $this->option; ?>&amp;controller=<?php echo $this->controller; ?>" method="post" name="adminForm" id="item-form">
 		<p class="warning"><?php echo JText::_('No management interface found for this plugin.'); ?></p>
-
+		
 		<input type="hidden" name="option" value="<?php echo $this->option; ?>" />
 		<input type="hidden" name="controller" value="<?php echo $this->controller; ?>" />
 		<input type="hidden" name="task" value="" />
