@@ -28,34 +28,34 @@
  */
 
 // Check to ensure this file is included in Joomla!
-defined('_JEXEC') or die('Restricted access');
+defined('_JEXEC') or die( 'Restricted access' );
 
-JToolBarHelper::title(JText::_('COM_SUPPORT_TICKETS') . ': ' . JText::_('COM_SUPPORT_CATEGORIES'), 'support.png');
+JToolBarHelper::title( JText::_( 'Ticket Categories' ), 'addedit.png' );
 JToolBarHelper::addNew();
 JToolBarHelper::editList();
 JToolBarHelper::deleteList();
 ?>
 <script type="text/javascript">
-function submitbutton(pressbutton)
+function submitbutton(pressbutton) 
 {
 	var form = document.adminForm;
 	if (pressbutton == 'cancel') {
-		submitform(pressbutton);
+		submitform( pressbutton );
 		return;
 	}
 	// do field validation
-	submitform(pressbutton);
+	submitform( pressbutton );
 }
 </script>
 
-<form action="index.php" method="post" name="adminForm" id="adminForm">
+<form action="index.php" method="post" name="adminForm">
 	<table class="adminlist">
 		<thead>
 			<tr>
-				<th scope="col"><input type="checkbox" name="toggle" value="" onclick="checkAll(<?php echo count( $this->rows );?>);" /></th>
-				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_SUPPORT_COL_ID', 'id', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
-				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_SUPPORT_COL_TITLE', 'title', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
-				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_SUPPORT_COL_ALIAS', 'alias', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
+				<th><input type="checkbox" name="toggle" value="" onclick="checkAll(<?php echo count( $this->rows );?>);" /></th>
+				<th><?php echo JText::_('SUPPORT_COL_ID'); ?></th>
+				<th><?php echo JText::_('SUPPORT_COL_CATEGORY'); ?></th>
+				<th><?php echo JText::_('SUPPORT_COL_SECTION'); ?></th>
 			</tr>
 		</thead>
 		<tfoot>
@@ -71,22 +71,10 @@ for ($i=0, $n=count( $this->rows ); $i < $n; $i++)
 	$row = &$this->rows[$i];
 ?>
 			<tr>
-				<td>
-					<input type="checkbox" name="id[]" id="cb<?php echo $i;?>" value="<?php echo $row->id ?>" onclick="isChecked(this.checked, this);" />
-				</td>
-				<td>
-					<?php echo $this->escape($row->id); ?>
-				</td>
-				<td>
-					<a href="index.php?option=<?php echo $this->option ?>&amp;controller=<?php echo $this->controller ?>&amp;task=edit&amp;id=<?php echo $row->id; ?>">
-						<?php echo $this->escape($row->title); ?>
-					</a>
-				</td>
-				<td>
-					<a href="index.php?option=<?php echo $this->option ?>&amp;controller=<?php echo $this->controller ?>&amp;task=edit&amp;id=<?php echo $row->id; ?>">
-						<?php echo $this->escape($row->alias); ?>
-					</a>
-				</td>
+				<td><input type="checkbox" name="id[]" id="cb<?php echo $i;?>" value="<?php echo $row->id ?>" onclick="isChecked(this.checked, this);" /></td>
+				<td><?php echo $row->id; ?></td>
+				<td><a href="index.php?option=<?php echo $this->option ?>&amp;controller=<?php echo $this->controller ?>&amp;task=edit&amp;id=<? echo $row->id; ?>"><?php echo $this->escape($row->category); ?></a></td>
+				<td><?php echo $this->escape($row->section); ?></td>
 			</tr>
 <?php
 	$k = 1 - $k;
@@ -99,8 +87,6 @@ for ($i=0, $n=count( $this->rows ); $i < $n; $i++)
 	<input type="hidden" name="controller" value="<?php echo $this->controller ?>" />
 	<input type="hidden" name="task" value="" />
 	<input type="hidden" name="boxchecked" value="0" />
-	<input type="hidden" name="filter_order" value="<?php echo $this->filters['sort']; ?>" />
-	<input type="hidden" name="filter_order_Dir" value="<?php echo $this->filters['sort_Dir']; ?>" />
 
-	<?php echo JHTML::_('form.token'); ?>
+	<?php echo JHTML::_( 'form.token' ); ?>
 </form>
