@@ -32,17 +32,14 @@
 defined('_JEXEC') or die('Restricted access');
 
 $item = $this->row->item();
-
-$content = $this->row->description('parsed');
-$content = ($content ?: $item->description('parsed'));
 ?>
 		<p class="link">
-			<a href="<?php echo stripslashes($item->get('url')); ?>" rel="external">
-				<?php echo $this->escape(stripslashes($item->get('title', $item->get('url')))); ?>
+			<a href="<?php echo stripslashes($item->get('url')); ?>">
+				<?php echo ($item->get('title')) ? $this->escape(stripslashes($item->get('title'))) : $this->escape(stripslashes($item->get('url'))); ?>
 			</a>
 		</p>
-<?php if ($content) { ?>
-		<div class="description">
-			<?php echo $content; ?>
-		</div>
+<?php if ($item->get('description') || $this->row->get('description')) { ?>
+		<p class="description">
+			<?php echo ($this->row->get('description')) ? $this->escape(stripslashes($this->row->get('description'))) : $this->escape(stripslashes($item->get('description'))); ?>
+		</p>
 <?php } ?>
\ No newline at end of file
