@@ -33,49 +33,49 @@ defined('_JEXEC') or die('Restricted access');
 
 /**
  * Turn querystring parameters into an SEF route
- *
+ * 
  * @param  array &$query Querystring
  */
 function CoursesBuildRoute(&$query)
 {
 	$segments = array();
 
-	if (!empty($query['controller']))
+	if (!empty($query['controller'])) 
 	{
-		if ($query['controller'] == 'certificate')
+		if($query['controller'] == 'form')
 		{
 			$segments[] = $query['controller'];
+
+			if(!empty($query['task']))
+			{
+				$segments[] = $query['task'];
+				unset($query['task']);
+			}
 		}
 		unset($query['controller']);
 	}
 
-	if (!empty($query['gid']))
+	if (!empty($query['gid'])) 
 	{
 		$segments[] = $query['gid'];
 		unset($query['gid']);
 	}
-	if (!empty($query['offering']))
+	if (!empty($query['offering'])) 
 	{
 		$segments[] = $query['offering'];
 		unset($query['offering']);
 	}
-	if (!empty($query['active']))
+	if (!empty($query['active'])) 
 	{
 		$segments[] = $query['active'];
-		if ($query['active'] == '' && !empty($query['task']))
+		if ($query['active'] == '' && !empty($query['task'])) 
 		{
 			$segments[] = $query['task'];
 			unset($query['task']);
 		}
 		unset($query['active']);
-	}
-	elseif (!empty($query['asset']))
-	{
-		$segments[] = 'asset';
-		$segments[] = $query['asset'];
-		unset($query['asset']);
-	}
-	else
+	} 
+	else 
 	{
 		if ((empty($query['scope']) || $query['scope'] == '') && !empty($query['task']))
 		{
@@ -83,17 +83,17 @@ function CoursesBuildRoute(&$query)
 			unset($query['task']);
 		}
 	}
-	if (!empty($query['unit']))
+	if (!empty($query['unit'])) 
 	{
 		$segments[] = $query['unit'];
 		unset($query['unit']);
 	}
-	if (!empty($query['b']))
+	if (!empty($query['b'])) 
 	{
 		$segments[] = $query['b'];
 		unset($query['b']);
 	}
-	if (!empty($query['c']))
+	if (!empty($query['c'])) 
 	{
 		$segments[] = $query['c'];
 		unset($query['c']);
@@ -104,9 +104,9 @@ function CoursesBuildRoute(&$query)
 
 /**
  * Parse a SEF route
- *
+ * 
  * @param  array $segments Exploded route
- * @return array
+ * @return array 
  */
 function CoursesParseRoute($segments)
 {
@@ -117,41 +117,17 @@ function CoursesParseRoute($segments)
 		return $vars;
 	}
 
-	if (isset($segments[0]))
+	if (isset($segments[0])) 
 	{
-		if (in_array($segments[0], array('intro', 'browse', 'badge')))
+		if (in_array($segments[0], array('intro', 'browse'))) 
 		{
 			$vars['controller'] = 'courses';
 			$vars['task'] = $segments[0];
-
-			if ($segments[0] == 'badge' && isset($segments[1]) && is_numeric($segments[1]))
-			{
-				$vars['badge_id'] = $segments[1];
-
-				if (in_array($segments[2], array('image', 'criteria', 'validation')))
-				{
-					$vars['action'] = $segments[2];
-
-					if ($segments[2] == 'validation' && isset($segments[3]))
-					{
-						$vars['validation_token'] = $segments[3];
-					}
-				}
-				return $vars;
-			}
 		}
-		else if ($segments[0] == 'certificate')
+		elseif ($segments[0] == 'form')
 		{
+			$vars['task'] = 'index';
 			$vars['controller'] = $segments[0];
-			if (isset($segments[1]))
-			{
-				$vars['course'] = $segments[1];
-			}
-			if (isset($segments[2]))
-			{
-				$vars['offering'] = $segments[2];
-			}
-			return $vars;
 		}
 		else
 		{
@@ -168,30 +144,50 @@ function CoursesParseRoute($segments)
 		}
 	}
 
-	if (isset($segments[1]))
+	/*if (isset($vars['gid']))
+	{
+		require_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_courses' . DS . 'tables' . DS . 'offering.php');
+		$inst = new CoursesTableInstance(JFactory::getDBO());
+		$insts = $inst->getCourseInstances(array(
+			'course_alias' => $vars['gid']
+		));
+		//$course = CoursesCourse::getInstance($vars['gid']);
+		if ($insts && count($insts) == 1)
+		{
+			JRequest::setVar('offering', $insts[0]->alias);
+			$vars['offering'] = $insts[0]->alias;
+			$vars['controller'] = 'offering';
+		}
+	}*/
+
+	if (isset($segments[1])) 
 	{
 		$vars['controller'] = 'course';
 		switch ($segments[1])
 		{
 			case 'overview':
-			case 'reviews':
-			case 'offerings':
-			case 'faq':
-				$vars['active'] = $segments[1];
+			case 'discussions':
+			case 'calendar':
+			case 'messages':
+			case 'enrollment':
+			case 'syllabus':
+				if (!isset($vars['offering']) && isset($vars['gid']))
+				{
+					require_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_courses' . DS . 'tables' . DS . 'instance.php');
+					$inst = new CoursesTableInstance(JFactory::getDBO());
+					$insts = $inst->getCourseInstances(array('course_alias' => $vars['gid']));
+					if ($insts && count($insts) == 1)
+					{
+						JRequest::setVar('offering', $insts[0]->alias);
+						$vars['offering'] = $insts[0]->alias;
+						//$vars['task'] = 'offering';
+						$vars['active'] = $segments[1];
+						$vars['controller'] = 'offering';
+					}
+				}
 			break;
 
-			case 'logo':
 			case 'edit':
-			case 'newoffering':
-			case 'saveoffering':
-			case 'deletepage':
-				$vars['task'] = $segments[1];
-			break;
-
-			case 'instructors':
-				$vars['controller'] = 'managers';
-			break;
-
 			case 'delete':
 			case 'join':
 			case 'accept':
@@ -199,18 +195,12 @@ function CoursesParseRoute($segments)
 			case 'invite':
 			case 'customize':
 			case 'manage':
-				if (isset($segments[2]))
+				if(isset($segments[2]))
 				{
 					$vars['task'] = 'editoutline';
 					$vars['offering'] = $segments[2];
 				}
 				$vars['controller'] = 'offering';
-				if (isset($segments[3]))
-				{
-					$vars['task'] = 'manage';
-					$vars['controller'] = $segments[3];
-				}
-				return $vars;
 			break;
 
 			case 'editoutline':
@@ -221,93 +211,49 @@ function CoursesParseRoute($segments)
 				$vars['controller'] = 'media';
 			break;
 
+			// Forms routes
+			case 'index':
+			case 'layout':
+			case 'upload':
+			case 'showDeployment':
+			case 'complete':
+				$vars['controller'] = 'form';
+				$vars['task']       = $segments[1];
+			break;
+
 			// Defaults
 			default:
-				$pagefound = false;
-				require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'course.php');
-				$course = CoursesModelCourse::getInstance($vars['gid']);
-				if ($course->exists())
-				{
-					$pages = $course->pages(array('active' => 1));
-
-					foreach ($pages as $page)
-					{
-						if ($page->get('url') == $segments[1])
-						{
-							$pagefound = true;
-							$vars['active'] = $segments[1];
-							break;
-						}
-					}
-				}
-
-				if (!$pagefound)
-				{
-					$vars['offering'] = $segments[1];
-					$vars['controller'] = 'offering';
-				}
+				$vars['offering'] = $segments[1];
+				$vars['controller'] = 'offering';
 			break;
 		}
 	}
 
-	if (isset($segments[2]))
+	if (isset($segments[2])) 
 	{
-		if ($segments[2] == 'form.index'
-			|| $segments[2] == 'form.layout'
-			|| $segments[2] == 'form.saveLayout'
-			|| $segments[2] == 'form.upload'
-			|| $segments[2] == 'form.deploy'
-			|| $segments[2] == 'form.showDeployment'
-			|| $segments[2] == 'form.complete')
+		if($segments[0] == 'form')
 		{
+			$vars['formId'] = $segments[2];
 			$vars['controller'] = 'form';
-			$vars['task']       = substr($segments[2], 5);
-		}
-		elseif ($segments[2] == 'asset' && isset($segments[3]) && is_numeric($segments[3]))
-		{
-			$vars['controller'] = 'offering';
-			$vars['task']       = 'asset';
-			$vars['asset_id']   = $segments[3];
-
-			if (isset($segments[4]))
-			{
-				$vars['file'] = $segments[4];
-			}
-		}
-		else if ($vars['controller'] == 'course' && isset($vars['active']))
-		{
-			$vars['task'] = 'download';
-			$vars['file'] = $segments[2];
 		}
 		else
 		{
-			if ($segments[2] == 'enroll' || $segments[2] == 'logo')
-			{
-				$vars['task'] = $segments[2];
-			}
-			else
-			{
-				$vars['active'] = $segments[2];
-			}
+			$vars['active'] = $segments[2];
 			$vars['controller'] = 'offering';
 		}
 	}
-	if (isset($segments[3]))
+	if (isset($segments[3])) 
 	{
 		$vars['unit'] = $segments[3];
 	}
-	if (isset($segments[4]))
+	if (isset($segments[4])) 
 	{
 		$vars['group'] = $segments[4];
 	}
-	if (isset($segments[5]))
+	if (isset($segments[5])) 
 	{
 		$vars['asset'] = $segments[5];
 	}
-	if (isset($segments[6]))
-	{
-		$vars['d'] = $segments[6];
-	}
 
 	return $vars;
 }
