@@ -32,49 +32,54 @@
 defined('_JEXEC') or die('Restricted access');
 
 /**
- * Table class for archived featured content
+ * Short description for 'FeaturesHistory'
+ * 
+ * Long description (if any) ...
  */
 class FeaturesHistory extends JTable
 {
-	/**
-	 * int(11)
-	 * 
-	 * @var intger
-	 */
-	var $id          = NULL;
 
 	/**
-	 * datetime(0000-00-00 00:00:00)
+	 * Description for 'id'
 	 * 
-	 * @var string
+	 * @var unknown
 	 */
-	var $featured    = NULL;
+	var $id          = NULL;  // int(11)
 
 	/**
-	 * string(100)
+	 * Description for 'featured'
 	 * 
-	 * @var string
+	 * @var unknown
 	 */
-	var $objectid    = NULL;
+	var $featured    = NULL;  // datetime(0000-00-00 00:00:00)
 
 	/**
-	 * string(100)
+	 * Description for 'objectid'
 	 * 
-	 * @var string
+	 * @var unknown
 	 */
-	var $tbl         = NULL;
+	var $objectid    = NULL;  // string(100)
 
 	/**
-	 * string(100)
+	 * Description for 'tbl'
 	 * 
-	 * @var string
+	 * @var unknown
 	 */
-	var $note        = NULL;
+	var $tbl         = NULL;  // string(100)
 
 	/**
-	 * Constructor
+	 * Description for 'note'
 	 * 
-	 * @param      object &$db JDatabase
+	 * @var unknown
+	 */
+	var $note        = NULL;  // string(100)
+
+	/**
+	 * Short description for '__construct'
+	 * 
+	 * Long description (if any) ...
+	 * 
+	 * @param      unknown &$db Parameter description (if any) ...
 	 * @return     void
 	 */
 	public function __construct(&$db)
@@ -83,52 +88,19 @@ class FeaturesHistory extends JTable
 	}
 
 	/**
-	 * Validate data
+	 * Short description for 'loadActive'
 	 * 
-	 * @return     boolean True if data is valid
-	 */
-	public function check()
-	{
-		$this->tbl = trim($this->tbl);
-		if ($this->tbl == '') 
-		{
-			$this->setError(JText::_('Please provide an Object type.'));
-		}
-
-		$this->objectid = intval($this->objectid);
-		if (!$this->objectid) 
-		{
-			$this->setError(JText::_('Please provide an Object ID.'));
-		}
-
-		if ($this->getError())
-		{
-			return false;
-		}
-
-		$this->note = trim($this->note);
-
-		if (!$this->featured) 
-		{
-			$this->featured = JFactory::getDate()->toSql();
-		}
-
-		return true;
-	}
-
-	/**
-	 * Load a record by featured time/date and object type
+	 * Long description (if any) ...
 	 * 
-	 * @param      string $start Featured timestamp
-	 * @param      string $tbl   Object type
-	 * @param      string $note  Optional note value to filter further by
-	 * @return     boolean True on success, False on error
+	 * @param      unknown $start Parameter description (if any) ...
+	 * @param      string $tbl Parameter description (if any) ...
+	 * @param      string $note Parameter description (if any) ...
+	 * @return     boolean Return description (if any) ...
 	 */
 	public function loadActive($start, $tbl='', $note='')
 	{
-		$query  = "SELECT * FROM $this->_tbl WHERE `featured`=" . $this->_db->Quote($start) . " AND `tbl`=" . $this->_db->Quote($tbl);
-		$query .= ($note) ? " AND `note`=" . $this->_db->Quote($note) : '';
-
+		$query  = "SELECT * FROM $this->_tbl WHERE featured='$start' AND tbl='$tbl'";
+		$query .= ($note) ? " AND note='$note'" : '';
 		$this->_db->setQuery($query);
 		if ($result = $this->_db->loadAssoc()) 
 		{
@@ -142,16 +114,17 @@ class FeaturesHistory extends JTable
 	}
 
 	/**
-	 * Load a record by object ID and object type
+	 * Short description for 'loadObject'
 	 * 
-	 * @param      integer $objectid Object ID
-	 * @param      string  $tbl      Object type
-	 * @return     boolean True on success, False on error
+	 * Long description (if any) ...
+	 * 
+	 * @param      unknown $objectid Parameter description (if any) ...
+	 * @param      string $tbl Parameter description (if any) ...
+	 * @return     boolean Return description (if any) ...
 	 */
 	public function loadObject($objectid, $tbl='')
 	{
-		$query = "SELECT * FROM $this->_tbl WHERE objectid=" . $this->_db->Quote(intval($objectid)) . " AND tbl=" . $this->_db->Quote((string) $tbl);
-
+		$query = "SELECT * FROM $this->_tbl WHERE objectid='$objectid' AND tbl='$tbl'";
 		$this->_db->setQuery($query);
 		if ($result = $this->_db->loadAssoc()) 
 		{
@@ -165,32 +138,36 @@ class FeaturesHistory extends JTable
 	}
 
 	/**
-	 * Get a record count
+	 * Short description for 'getCount'
 	 * 
-	 * @param      array   $filters    Filters to apply to query
-	 * @param      boolean $authorized Is the user an admin?
-	 * @return     integer
+	 * Long description (if any) ...
+	 * 
+	 * @param      array $filters Parameter description (if any) ...
+	 * @param      boolean $authorized Parameter description (if any) ...
+	 * @return     object Return description (if any) ...
 	 */
 	public function getCount($filters=array(), $authorized=false)
 	{
 		$query  = "SELECT COUNT(*)";
-		$query .= $this->_buildQuery($filters, $authorized);
+		$query .= $this->buildQuery($filters, $authorized);
 
 		$this->_db->setQuery($query);
 		return $this->_db->loadResult();
 	}
 
 	/**
-	 * Get a list of records
+	 * Short description for 'getRecords'
 	 * 
-	 * @param      array   $filters    Filters to apply to query
-	 * @param      boolean $authorized Is the user an admin?
-	 * @return     array
+	 * Long description (if any) ...
+	 * 
+	 * @param      array $filters Parameter description (if any) ...
+	 * @param      boolean $authorized Parameter description (if any) ...
+	 * @return     object Return description (if any) ...
 	 */
 	public function getRecords($filters=array(), $authorized=false)
 	{
 		$query  = "SELECT *";
-		$query .= $this->_buildQuery($filters, $authorized);
+		$query .= $this->buildQuery($filters, $authorized);
 		if (isset($filters['limit']) && $filters['limit'] != 'all' && $filters['limit'] != '0') 
 		{
 			$query .= " LIMIT " . $filters['start'] . ", " . $filters['limit'];
@@ -201,20 +178,24 @@ class FeaturesHistory extends JTable
 	}
 
 	/**
-	 * Build a query from an array of filters
+	 * Short description for 'buildQuery'
 	 * 
-	 * @param      array   $filters    Filters to apply to query
-	 * @param      boolean $authorized Is the user an admin?
-	 * @return     string
+	 * Long description (if any) ...
+	 * 
+	 * @param      array $filters Parameter description (if any) ...
+	 * @param      boolean $authorized Parameter description (if any) ...
+	 * @return     string Return description (if any) ...
 	 */
-	private function _buildQuery($filters=array(), $authorized=false)
+	public function buildQuery($filters=array(), $authorized=false)
 	{
-		$query  = " FROM $this->_tbl AS f ";
+		$juser =& JFactory::getUser();
 
-		$where = array();
+		// build body of query
+		$query  = " FROM $this->_tbl AS f ";
 
 		if (isset($filters['type']) && $filters['type'] != '') 
 		{
+			$query .= " WHERE";
 			if ($filters['type'] == 'tools') 
 			{
 				$filters['type'] = 'resources';
@@ -224,22 +205,33 @@ class FeaturesHistory extends JTable
 			{
 				$filters['note'] = 'nontools';
 			}
-			$where[] = "f.`tbl`=" . $this->_db->Quote($filters['type']);
+			$query .= " f.tbl='" . $filters['type'] . "' ";
 		}
 		if (isset($filters['note']) && $filters['note'] != '') 
 		{
-			$where[] = "f.`note`=" . $this->_db->Quote($filters['note']);
+			if (isset($filters['type']) && $filters['type'] != '') 
+			{
+				$query .= " AND";
+			} 
+			else 
+			{
+				$query .= " WHERE";
+			}
+			$query .= " f.note='" . $filters['note'] . "' ";
 		}
 		if (!$authorized) 
 		{
-			$where[] = "f.featured <= " . $this->_db->Quote(JFactory::getDate()->toSql());
+			$now = date('Y-m-d H:i:s');
+			if (isset($filters['note']) && $filters['note'] != '' && isset($filters['type']) && $filters['type'] != '') 
+			{
+				$query .= " AND";
+			} 
+			else 
+			{
+				$query .= " WHERE";
+			}
+			$query .= " f.featured <= '$now'";
 		}
-
-		if (count($where) > 0)
-		{
-			$query .= " WHERE " . implode(" AND ", $where);
-		}
-
 		$query .= " ORDER BY f.featured DESC, f.id ASC";
 
 		return $query;
