@@ -36,7 +36,7 @@ $emailbody .= JText::_('COM_STORE_EMAIL_KEEP') . "\n";
 $emailbody .= '----------------------------------------------------------' . "\n";
 $emailbody .= ' ' . JText::_('COM_STORE_ORDER') . ' ' . JText::_('COM_STORE_NUM') . ': ' . $this->orderid . "\n";
 $emailbody .= ' ' . JText::_('ORDER') . ' ' . JText::_('TOTAL') . ': ' . $this->cost . ' ' . JText::_('POINTS') . "\n";
-$emailbody .= ' ' . JText::_('PLACED') . ' ' . JHTML::_('date', $this->now, JText::_('DATE_FORMAT_HZ1')) . "\n";
+$emailbody .= ' ' . JText::_('PLACED') . ' ' . JHTML::_('date', $this->now, '%d %b, %Y') . "\n";
 $emailbody .= ' ' . JText::_('STATUS') . ': ' . JText::_('RECEIVED') . "\n";
 $emailbody .= '----------------------------------------------------------' . "\n";
 $emailbody .= $this->details . "\n";
@@ -45,4 +45,4 @@ $emailbody .= JText::_('COM_STORE_EMAIL_ORDER_PROCESSED') . '. ';
 $emailbody .= JText::_('COM_STORE_EMAIL_QUESTIONS') . '.' . "\n\n";
 $emailbody .= JText::_('COM_STORE_EMAIL_THANKYOU') . "\n";
 
-echo $emailbody;
+echo $emailbody;
\ No newline at end of file
