@@ -62,7 +62,7 @@ class plgContentXhubtags extends JPlugin
 	public function onPrepareContent(&$article, &$params, $page = 0)
 	{
 		$context = '';
-		return $this->onContentPrepare($context, &$article, &$params, $page);
+		return $this->onContentPrepare($context, $article, $params, $page);
 	}
 
 	/**
@@ -322,4 +322,4 @@ class plgContentXhubtags extends JPlugin
 		
 		return '';
 	}
-}
\ No newline at end of file
+}
